import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { Cell } from '..';
describe('Cell', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render value slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      value: "Custom Value"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render title slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Custom Title"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render label slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      label: "Custom Label"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render icon slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      icon: "location-o"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render extra slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      value: "Value",
      extra: "Custom Extra"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should change arrow direction when using arrow-direction prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      value: "Value",
      isLink: true,
      arrowDirection: "down"
    }));
    expect(wrapper.find('.rc-cell__right-icon').exists()).toBeTruthy();
    expect(wrapper.find('.van-icon-arrow-down').exists()).toBeTruthy();
  });
  it('should change title style when using title-style prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      titleStyle: {
        color: 'red'
      }
    }));
    var title = wrapper.find('.rc-cell__title');
    expect(title.getDOMNode().style.color).toEqual('red');
  });
  it('should change icon class prefix when using icon-prefix prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      icon: "success",
      iconPrefix: "my-icon"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should allow to disable clicakble when using is-link prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      isLink: true,
      clickable: false
    }));
    expect(wrapper.find('.rc-cell--clickable').exists()).toBeTruthy();
  });
});